.. _glossary:

########
Glossary
########

.. glossary::
    :sorted:
    
    Shared Model
        The part of your model which holds the **untranslated** fields.
        Internally this is a separated model to your :term:`Translations Model`
        as well as it's own database table.
    
    Translations Model
        The part of your model which holds the **translated** fields. Internally
        this is a (autogenerated) separate model with a ForeignKey to your
        :term:`Shared Model`.
    
    Shared Fields
        A field which is not translated, thus *shared* between the languages.
        
    Translated Fields
        A field which is translatable on a model.
        
    Normal Model
        A Django model that does not have :term:`Translated Fields`.
        
    Translated Model
        A Django model that subclasses :class:`~hvad.models.TranslatableModel`.

    Translation Manager
        A subclass of :class:`~hvad.manager.TranslationManager`, which replaces
        the default Django manager on Translated Model, allowing access to
        translated fields. It will use :class:`~hvad.manager.TranslationQueryset`
        internally, or a custom subclass if so configured.

    Translation-Aware Manager
        A Django manager that operates on **untranslated** models, yet is aware of
        translated models it meets when crossing relations. It makes it possible
        to filter untranslatable models against a translated field of a related
        model.
